package com.emn308.disabledstatusbar

import android.app.admin.DeviceAdminReceiver
import android.app.admin.DevicePolicyManager
import android.content.ComponentName
import android.content.Context
import android.content.Intent
import android.os.Handler
import android.os.Looper
import android.util.Log

class Admin : DeviceAdminReceiver() {
    companion object {
        private const val TAG = "DisabledStatusBarAdmin"
    }

    override fun onEnabled(context: Context, intent: Intent) {
        super.onEnabled(context, intent)
        Log.d(TAG, "Admin enabled")

        val deviceAdminComponent = ComponentName(context, Admin::class.java)
        val dpm = context.getSystemService(Context.DEVICE_POLICY_SERVICE) as DevicePolicyManager
        if (dpm.isDeviceOwnerApp(context.packageName)) {
            dpm.setStatusBarDisabled(deviceAdminComponent, true)
        }
        Handler(Looper.getMainLooper()).postDelayed({
            if (dpm.isAdminActive(deviceAdminComponent)) {
                Log.d(TAG, "Admin is active")
                try {
                    // Check if we have the necessary permissions
                    if (dpm.isDeviceOwnerApp(context.packageName)) {
                        Log.d(TAG, "App is device owner, attempting to disable status bar")
                        dpm.setStatusBarDisabled(deviceAdminComponent, true)
                        Log.d(TAG, "Status bar disabled successfully")
                    } else {
                        Log.w(TAG, "App is not device owner")
                    }
                } catch (e: SecurityException) {
                    Log.e(TAG, "Failed to disable status bar: ${e.message}", e)
                }
            } else {
                Log.w(TAG, "Admin is not active")
            }
        }, 2000) // Wait for 2 seconds
    }

    override fun onDisabled(context: Context, intent: Intent) {
        super.onDisabled(context, intent)
        Log.d(TAG, "Admin disabled")
    }
}